@@ -5,11 +5,10 @@ from datomizer.helpers.common_helper import get_flow, wait_for_step_type, get_ge
 from datomizer.helpers.generator.generator_helper import generate, assert_output_ratio
 from datomizer.helpers.datasource.datasource_helper import create_target_private_datasource
 from datomizer.utils.general import TARGET_DATASOURCE_ID, ERROR
-from datomizer.utils.interfaces import DatoGenInterface
 from datomizer.utils.step_types import GENERATE
 
 
-class DatoGenerator(DatoGenInterface):
+class DatoGenerator(object):
     dato_trainer: DatoTrainer
     synth_id = 0
     datasource_id = 0
@@ -68,9 +67,6 @@ class DatoGenerator(DatoGenInterface):
             raise Exception("Synth Failed")
         self.datasource_id = self.get_flow()[TARGET_DATASOURCE_ID]
 
-    def list_tables(self):
-        return self.dato_trainer.dato_mapper.schema.tables_name()
-
     def get_generated_data(self) -> None:
         self.restore_validation()
         print(get_generated_zip(datomizer=self.dato_trainer.dato_mapper.datomizer,
