@@ -3,6 +3,8 @@ import requests
 from datomizer import DatoTrainer
 from datomizer.utils.constants import MANAGEMENT_PUT_SYNTH_FLOW
 from datomizer.utils.general import ID, NEW_PRIVATE_ID, SPARK_WRITE_OPTIONS_OVERWRITE
+from datomizer.utils.messages import OUTPUT_RATIO_INVALID
+from datomizer.utils.thresholds import MIN_RATIO, MAX_RATIO
 
 
 def create_synth_request(dato_trainer: DatoTrainer,
@@ -29,3 +31,7 @@ def generate(dato_trainer: DatoTrainer, datasource_id: int, output_ratio: float
         headers={"Content-Type": "application/json"},
         data=json.dumps(create_synth_request(dato_trainer, datasource_id, output_ratio)))
     return response_json[ID]
+
+
+def assert_output_ratio(output_ratio: float = 1):
+    assert MIN_RATIO <= output_ratio <= MAX_RATIO, OUTPUT_RATIO_INVALID % (output_ratio, MIN_RATIO, MAX_RATIO)
