@@ -41,6 +41,6 @@ def map_enum_list(enum_list: []):
     return [obj.value for obj in enum_list]
 
 
-def assert_column_valid_for_eml(column: ColumnDTO):
+def assert_column_valid_for_eml(column: ColumnDTO) -> bool:
     assert column.role == Roles.LABEL.value, EML_TARGET_INVALID_ROLE
     assert 2 <= column.uniqueCount <= 10, EML_TARGET_INVALID_UNIQUE_COUNT
