@@ -14,6 +14,9 @@ REFRESH_TOKEN = "refresh_token"
 
 TRAIN_ITERATIONS = "trainIterations"
 STEPS = "steps"
+TASKS = "tasks"
+TASK_STATUS = "taskStatus"
+STEP_TYPE = "stepType"
 ORIGIN_DATASOURCE_ID = "originDataSourceId"
 TARGET_DATASOURCE_ID = "targetDataSourceId"
 MODELS = "models"
