@@ -3,4 +3,4 @@ EML_TARGET_INVALID_UNIQUE_COUNT = "The selected target is invalid. We currently
 COLUMN_NOT_EXISTS = "The selected target is invalid. No such field exists in the input data."
 
 OUTPUT_RATIO_INVALID = "Invalid output_ratio: %s. The permitted range is %s - %s"
-MISSING_TARGET_COLUMN = "Missing the target_column argument."
+MISSING_TARGET_TABLE = "Missing the target_column argument."
